@@ -247,8 +247,11 @@ def test_user_session_is_preserved():
 
 
 def test_idempotent_connect(s3):
-    first = s3.s3
-    assert s3.connect(refresh=True) is not first
+    stale_s3 = s3.s3
+    stale_session = s3.session
+    s3.connect(refresh=True)
+    assert stale_s3 is not s3.s3
+    assert stale_session is not s3.session
 
 
 def test_multiple_objects(s3):
@@ -269,7 +272,7 @@ def test_info(s3):
     info.pop("ContentType")
     linfo.pop("Key")
     linfo.pop("Size")
-    linfo.pop("ChecksumAlgorithm")
+    linfo.pop("ChecksumAlgorithm", None)  # field DNE in some S3-compatible providers
     assert info == linfo
     parent = a.rsplit("/", 1)[0]
     s3.invalidate_cache()  # remove full path from the cache
